==> dde-introduction_5.6.35.orig.tar.xz: dde-introduction-5.6.35/translations/dde-introduction_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>BottomNavigation</name>
    <message>
        <source>Community</source>
        <translation>Komunita</translation>
    </message>
    <message>
        <source>Feeback</source>
        <translation>Zpětná vazba</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Acknowledgments</source>
        <translation>Poděkování</translation>
    </message>
</context>
<context>
    <name>DesktopModeModule</name>
    <message>
        <source>Efficient Mode</source>
        <translation>Účelný režim</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Módní režim</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>Vyberte režim plochy</translation>
    </message>
    <message>
        <source>You can switch modes by right clicking on the dock</source>
        <translation>Režimy můžete přepnout kliknutím pravým tlačítkem myši na panel</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>Vyberte režim provozování</translation>
    </message>
    <message>
        <source>You can switch it in Control Center &gt; Personalization &gt; Window effect</source>
        <translation>Můžete přepnout v Ovládací panely → Přizpůsobení → Vzhled → Efekty pro okna</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>Vyberte vzhled ikon</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>Můžete změnit v Ovládací panely → Přizpůsobení → Vzhled → Vzhled ikon</translation>
    </message>
</context>
<context>
    <name>NormalModule</name>
    <message>
        <source>Introduction</source>
        <translation>Úvod</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation>Vítejte</translation>
    </message>
    <message>
        <source>Desktop Mode</source>
        <translation>Režim plochy</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>Vyberte režim plochy</translation>
    </message>
    <message>
        <source>You can switch modes by right clicking on the dock</source>
        <translation>Režimy můžete přepnout kliknutím pravým tlačítkem myši na panel</translation>
    </message>
    <message>
        <source>Running Mode</source>
        <translation>Režim provozování</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>Vyberte režim provozování</translation>
    </message>
    <message>
        <source>Please choose normal mode if you has a low configuration computer</source>
        <translation>Pokud máte méně výkonný počítač, zvolte střídmý režim</translation>
    </message>
    <message>
        <source>Icon Theme</source>
        <translation>Vzhled ikon</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>Vyberte vzhled ikon</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>Můžete změnit v Ovládací panely → Přizpůsobení → Vzhled ikon</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Welcome</source>
        <translation>Vítejte</translation>
    </message>
</context>
<context>
    <name>WMModeModule</name>
    <message>
        <source>Normal Mode</source>
        <translation>Střídmý režim</translation>
    </message>
    <message>
        <source>Effect Mode</source>
        <translation>Líbivý režim</translation>
    </message>
</context>
</TS>

==> dde-introduction_5.6.38.orig.tar.xz: dde-introduction-5.6.38/translations/dde-introduction_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>BottomNavigation</name>
    <message>
        <source>Community</source>
        <translation>Komunita</translation>
    </message>
    <message>
        <source>Feeback</source>
        <translation>Zpětná vazba</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Acknowledgments</source>
        <translation>Poděkování</translation>
    </message>
</context>
<context>
    <name>DesktopModeModule</name>
    <message>
        <source>Efficient Mode</source>
        <translation>Účelný režim</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Módní režim</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>Vyberte režim plochy</translation>
    </message>
    <message>
        <source>You can switch modes by right clicking on the dock</source>
        <translation>Režimy můžete přepnout klepnutím pravým tlačítkem myši na panel</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>Vyberte režim provozování</translation>
    </message>
    <message>
        <source>You can switch it in Control Center &gt; Personalization &gt; Window effect</source>
        <translation>Můžete přepnout v Ovládací panely → Přizpůsobení → Vzhled → Efekty pro okna</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>Vyberte vzhled ikon</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>Můžete změnit v Ovládací panely → Přizpůsobení → Vzhled → Vzhled ikon</translation>
    </message>
</context>
<context>
    <name>NormalModule</name>
    <message>
        <source>Introduction</source>
        <translation>Úvod</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation>Vítejte</translation>
    </message>
    <message>
        <source>Desktop Mode</source>
        <translation>Režim plochy</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>Vyberte režim plochy</translation>
    </message>
    <message>
        <source>You can switch modes by right clicking on the dock</source>
        <translation>Režimy můžete přepnout klepnutím pravým tlačítkem myši na panel</translation>
    </message>
    <message>
        <source>Running Mode</source>
        <translation>Režim provozování</translation>
    </message>
    <message>
        <source>Choose a running mode</source>
        <translation>Vyberte režim provozování</translation>
    </message>
    <message>
        <source>Please choose normal mode if you has a low configuration computer</source>
        <translation>Pokud máte méně výkonný počítač, zvolte střídmý režim</translation>
    </message>
    <message>
        <source>Icon Theme</source>
        <translation>Vzhled ikon</translation>
    </message>
    <message>
        <source>Choose an icon theme</source>
        <translation>Vyberte vzhled ikon</translation>
    </message>
    <message>
        <source>Change it in Control Center &gt; Personalization &gt; Icon Theme</source>
        <translation>Můžete změnit v Ovládací panely → Přizpůsobení → Vzhled ikon</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Welcome</source>
        <translation>Vítejte</translation>
    </message>
</context>
<context>
    <name>WMModeModule</name>
    <message>
        <source>Normal Mode</source>
        <translation>Střídmý režim</translation>
    </message>
    <message>
        <source>Effect Mode</source>
        <translation>Líbivý režim</translation>
    </message>
</context>
</TS>
